@@ -1,24 +1,25 @@
 .plt.mat <-
-function(x, coef=TRUE, fit="loess",
-         col.fill=getOption("pt.fill"), col.stroke=getOption("pt.stroke"),
-         col.fit=getOption("bar.stroke"), col.bg=getOption("bg.fill"),
-         col.box=getOption("bg.stroke")) {
+function(x, cor.coef=TRUE, fit="loess",
+         col.fill=getOption("pt.fill"), col.color=getOption("pt.color"),
+         col.fit=getOption("bar.color"), col.bg=getOption("panel.fill"),
+         col.box=getOption("panel.color")) {
 
 
   if (is.null(fit)) fit <- "loess"
 
-  if (getOption("sub.theme") == "black") col.stroke <- getOption("lab.stroke")
+  if (getOption("sub.theme") == "black") col.color <- getOption("lab.color")
 
   n.var <- ncol(x)
 
-  par(bg=getOption("device.fill"))
+  par(bg=getOption("window.fill"))
 
   panel.smooth <- function (x, y, fit.line=fit, pch=par("pch"), cex=.76,
-    col.pt=col.stroke, col.smooth=col.fit, span=2/3, iter=3, ...)
+    col.pt=col.color, col.smooth=col.fit, span=2/3, iter=3, ...)
  {
     usr <- par("usr")          
     rect(usr[1], usr[3], usr[2], usr[4], col=col.bg, border=col.box)
-    points(x, y, pch=21, col=col.pt, bg=col.fill, cex=cex)
+    cex.adj <- 0.86 - 0.045*n.var
+    points(x, y, pch=21, col=col.pt, bg=col.fill, cex=cex.adj)
 
     ok <- is.finite(x) & is.finite(y)
     if (any(ok)) {
@@ -41,22 +42,25 @@ function(x, coef=TRUE, fit="loess",
     r <- cor(x, y)
     txt <- .fmt(r, 2)
     txt <- paste(prefix, txt, sep="")
-    if (missing(cex.cor)) cex.cor <- .9/strwidth(txt)
-    cex.adj <- 2.5 - (0.18*n.var)  # adjust size of displayed r
-    text(0.5, 0.5, txt, cex=cex.adj, col=col.stroke)  # or cex=cex.cor * r
+    cex.adj <- 2.25 - (0.10*n.var)  # adjust size of displayed r
+    text(0.5, 0.5, txt, cex=cex.adj, col=col.color)  # or cex=cex.cor * r
   }
 
   text.diag <- function(x, y, nm, ...) {  # nm from calling routine
     usr <- par("usr")          
-    rect(usr[1], usr[3], usr[2], usr[4], col=col.bg, border=col.box)
+    rect(usr[1], usr[3], usr[2], usr[4], col=getOption("ellipse.fill"),
+         border=col.box)
+    #rect(usr[1], usr[3], usr[2], usr[4], col=col.bg, border=col.box)
     txt <-  nm  # nm from parameter list, so adjusts for each panel
-    text(0.5, 0.5, txt, cex=1.8, col=getOption("lab.stroke"))
+    cex.adj <- 2.25 - (0.10*n.var)  # adjust size of displayed r
+    #cex.adj <- ifelse (n.var < 8, 1.8, 1.5)  # adjust size of displayed r
+    text(0.5, 0.5, txt, cex=cex.adj, col=getOption("lab.color"))
   }
 
   # -----
   # begin
 
-  if (coef)  # no missing data
+  if (cor.coef)  # no missing data
     pairs(na.omit(x), lower.panel=panel.smooth, upper.panel=panel.cor,
       text.panel=text.diag)
   else
